"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
This Source Code Form is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ResourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FEATURE: _ResourceType.ValueType  # 0
    LABEL: _ResourceType.ValueType  # 1
    TRAINING_SET: _ResourceType.ValueType  # 2
    SOURCE: _ResourceType.ValueType  # 3
    FEATURE_VARIANT: _ResourceType.ValueType  # 4
    LABEL_VARIANT: _ResourceType.ValueType  # 5
    TRAINING_SET_VARIANT: _ResourceType.ValueType  # 6
    SOURCE_VARIANT: _ResourceType.ValueType  # 7
    PROVIDER: _ResourceType.ValueType  # 8
    ENTITY: _ResourceType.ValueType  # 9
    MODEL: _ResourceType.ValueType  # 10
    USER: _ResourceType.ValueType  # 11

class ResourceType(_ResourceType, metaclass=_ResourceTypeEnumTypeWrapper): ...

FEATURE: ResourceType.ValueType  # 0
LABEL: ResourceType.ValueType  # 1
TRAINING_SET: ResourceType.ValueType  # 2
SOURCE: ResourceType.ValueType  # 3
FEATURE_VARIANT: ResourceType.ValueType  # 4
LABEL_VARIANT: ResourceType.ValueType  # 5
TRAINING_SET_VARIANT: ResourceType.ValueType  # 6
SOURCE_VARIANT: ResourceType.ValueType  # 7
PROVIDER: ResourceType.ValueType  # 8
ENTITY: ResourceType.ValueType  # 9
MODEL: ResourceType.ValueType  # 10
USER: ResourceType.ValueType  # 11
global___ResourceType = ResourceType

class _ComputationMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ComputationModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ComputationMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRECOMPUTED: _ComputationMode.ValueType  # 0
    CLIENT_COMPUTED: _ComputationMode.ValueType  # 1
    STREAMING: _ComputationMode.ValueType  # 2

class ComputationMode(_ComputationMode, metaclass=_ComputationModeEnumTypeWrapper): ...

PRECOMPUTED: ComputationMode.ValueType  # 0
CLIENT_COMPUTED: ComputationMode.ValueType  # 1
STREAMING: ComputationMode.ValueType  # 2
global___ComputationMode = ComputationMode

class _ScalarType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScalarTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScalarType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NULL: _ScalarType.ValueType  # 0
    INT: _ScalarType.ValueType  # 1
    FLOAT32: _ScalarType.ValueType  # 2
    FLOAT64: _ScalarType.ValueType  # 3
    STRING: _ScalarType.ValueType  # 4
    BOOL: _ScalarType.ValueType  # 5
    INT32: _ScalarType.ValueType  # 6
    INT64: _ScalarType.ValueType  # 7
    DATETIME: _ScalarType.ValueType  # 8

class ScalarType(_ScalarType, metaclass=_ScalarTypeEnumTypeWrapper): ...

NULL: ScalarType.ValueType  # 0
INT: ScalarType.ValueType  # 1
FLOAT32: ScalarType.ValueType  # 2
FLOAT64: ScalarType.ValueType  # 3
STRING: ScalarType.ValueType  # 4
BOOL: ScalarType.ValueType  # 5
INT32: ScalarType.ValueType  # 6
INT64: ScalarType.ValueType  # 7
DATETIME: ScalarType.ValueType  # 8
global___ScalarType = ScalarType

@typing.final
class OktaAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    AUTHORIZATION_SERVER_ID_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    domain: builtins.str
    authorization_server_id: builtins.str
    client_id: builtins.str
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        authorization_server_id: builtins.str = ...,
        client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["authorization_server_id", b"authorization_server_id", "client_id", b"client_id", "domain", b"domain"]) -> None: ...

global___OktaAuthConfig = OktaAuthConfig

@typing.final
class PassThroughAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PassThroughAuthConfig = PassThroughAuthConfig

@typing.final
class AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OKTA_FIELD_NUMBER: builtins.int
    PASS_THROUGH_FIELD_NUMBER: builtins.int
    @property
    def okta(self) -> global___OktaAuthConfig: ...
    @property
    def pass_through(self) -> global___PassThroughAuthConfig: ...
    def __init__(
        self,
        *,
        okta: global___OktaAuthConfig | None = ...,
        pass_through: global___PassThroughAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "okta", b"okta", "pass_through", b"pass_through"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "okta", b"okta", "pass_through", b"pass_through"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["okta", "pass_through"] | None: ...

global___AuthConfig = AuthConfig

@typing.final
class Name(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___Name = Name

@typing.final
class ErrorStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    code: builtins.int
    """The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code]."""
    message: builtins.str
    """A developer-facing error message, which should be in English. Any
    user-facing error message should be localized and sent in the
    [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.
    """
    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """A list of messages that carry the error details.  There will be a
        common set of message types for APIs to use.
        """

    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
        details: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "details", b"details", "message", b"message"]) -> None: ...

global___ErrorStatus = ErrorStatus

@typing.final
class ResourceStatus(google.protobuf.message.Message):
    """TODO: Deprecate this field in buildable resources when scheduling is fully implemented"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResourceStatus._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NO_STATUS: ResourceStatus._Status.ValueType  # 0
        CREATED: ResourceStatus._Status.ValueType  # 1
        PENDING: ResourceStatus._Status.ValueType  # 2
        READY: ResourceStatus._Status.ValueType  # 3
        FAILED: ResourceStatus._Status.ValueType  # 4
        RUNNING: ResourceStatus._Status.ValueType  # 5
        CANCELLED: ResourceStatus._Status.ValueType  # 6

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    NO_STATUS: ResourceStatus.Status.ValueType  # 0
    CREATED: ResourceStatus.Status.ValueType  # 1
    PENDING: ResourceStatus.Status.ValueType  # 2
    READY: ResourceStatus.Status.ValueType  # 3
    FAILED: ResourceStatus.Status.ValueType  # 4
    RUNNING: ResourceStatus.Status.ValueType  # 5
    CANCELLED: ResourceStatus.Status.ValueType  # 6

    STATUS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_STATUS_FIELD_NUMBER: builtins.int
    status: global___ResourceStatus.Status.ValueType
    error_message: builtins.str
    @property
    def error_status(self) -> global___ErrorStatus: ...
    def __init__(
        self,
        *,
        status: global___ResourceStatus.Status.ValueType = ...,
        error_message: builtins.str = ...,
        error_status: global___ErrorStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["error_status", b"error_status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["error_message", b"error_message", "error_status", b"error_status", "status", b"status"]) -> None: ...

global___ResourceStatus = ResourceStatus

@typing.final
class ResourceID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    resource_type: global___ResourceType.ValueType
    @property
    def resource(self) -> global___NameVariant: ...
    def __init__(
        self,
        *,
        resource: global___NameVariant | None = ...,
        resource_type: global___ResourceType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "resource_type", b"resource_type"]) -> None: ...

global___ResourceID = ResourceID

@typing.final
class SetStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_id(self) -> global___ResourceID: ...
    @property
    def status(self) -> global___ResourceStatus: ...
    def __init__(
        self,
        *,
        resource_id: global___ResourceID | None = ...,
        status: global___ResourceStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_id", b"resource_id", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "status", b"status"]) -> None: ...

global___SetStatusRequest = SetStatusRequest

@typing.final
class ScheduleChangeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    schedule: builtins.str
    @property
    def resource_id(self) -> global___ResourceID: ...
    def __init__(
        self,
        *,
        resource_id: global___ResourceID | None = ...,
        schedule: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "schedule", b"schedule"]) -> None: ...

global___ScheduleChangeRequest = ScheduleChangeRequest

@typing.final
class NameVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "variant", b"variant"]) -> None: ...

global___NameVariant = NameVariant

@typing.final
class Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

@typing.final
class Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_VARIANT_FIELD_NUMBER: builtins.int
    VARIANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    default_variant: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def variants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        default_variant: builtins.str = ...,
        variants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_variant", b"default_variant", "name", b"name", "status", b"status", "variants", b"variants"]) -> None: ...

global___Feature = Feature

@typing.final
class Columns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    entity: builtins.str
    value: builtins.str
    ts: builtins.str
    def __init__(
        self,
        *,
        entity: builtins.str = ...,
        value: builtins.str = ...,
        ts: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entity", b"entity", "ts", b"ts", "value", b"value"]) -> None: ...

global___Columns = Columns

@typing.final
class PythonFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.bytes
    def __init__(
        self,
        *,
        query: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["query", b"query"]) -> None: ...

global___PythonFunction = PythonFunction

@typing.final
class Stream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFLINE_PROVIDER_FIELD_NUMBER: builtins.int
    offline_provider: builtins.str
    def __init__(
        self,
        *,
        offline_provider: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["offline_provider", b"offline_provider"]) -> None: ...

global___Stream = Stream

@typing.final
class ResourceVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_VARIANT_FIELD_NUMBER: builtins.int
    LABEL_VARIANT_FIELD_NUMBER: builtins.int
    TRAINING_SET_VARIANT_FIELD_NUMBER: builtins.int
    SOURCE_VARIANT_FIELD_NUMBER: builtins.int
    @property
    def feature_variant(self) -> global___FeatureVariant: ...
    @property
    def label_variant(self) -> global___LabelVariant: ...
    @property
    def training_set_variant(self) -> global___TrainingSetVariant: ...
    @property
    def source_variant(self) -> global___SourceVariant: ...
    def __init__(
        self,
        *,
        feature_variant: global___FeatureVariant | None = ...,
        label_variant: global___LabelVariant | None = ...,
        training_set_variant: global___TrainingSetVariant | None = ...,
        source_variant: global___SourceVariant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["feature_variant", b"feature_variant", "label_variant", b"label_variant", "resource", b"resource", "source_variant", b"source_variant", "training_set_variant", b"training_set_variant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["feature_variant", b"feature_variant", "label_variant", b"label_variant", "resource", b"resource", "source_variant", b"source_variant", "training_set_variant", b"training_set_variant"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["resource", b"resource"]) -> typing.Literal["feature_variant", "label_variant", "training_set_variant", "source_variant"] | None: ...

global___ResourceVariant = ResourceVariant

@typing.final
class FeatureVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    LAST_UPDATED_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_ID_LIST_FIELD_NUMBER: builtins.int
    ADDITIONAL_PARAMETERS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    entity: builtins.str
    owner: builtins.str
    description: builtins.str
    provider: builtins.str
    schedule: builtins.str
    mode: global___ComputationMode.ValueType
    task_id: builtins.str
    @property
    def source(self) -> global___NameVariant: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def columns(self) -> global___Columns: ...
    @property
    def function(self) -> global___PythonFunction: ...
    @property
    def stream(self) -> global___Stream: ...
    @property
    def last_updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    @property
    def task_id_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_parameters(self) -> global___FeatureParameters: ...
    @property
    def type(self) -> global___ValueType: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        source: global___NameVariant | None = ...,
        entity: builtins.str = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        owner: builtins.str = ...,
        description: builtins.str = ...,
        provider: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        columns: global___Columns | None = ...,
        function: global___PythonFunction | None = ...,
        stream: global___Stream | None = ...,
        last_updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        schedule: builtins.str = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
        mode: global___ComputationMode.ValueType = ...,
        task_id: builtins.str = ...,
        task_id_list: collections.abc.Iterable[builtins.str] | None = ...,
        additional_parameters: global___FeatureParameters | None = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["additional_parameters", b"additional_parameters", "columns", b"columns", "created", b"created", "function", b"function", "last_updated", b"last_updated", "location", b"location", "properties", b"properties", "source", b"source", "status", b"status", "stream", b"stream", "tags", b"tags", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_parameters", b"additional_parameters", "columns", b"columns", "created", b"created", "description", b"description", "entity", b"entity", "function", b"function", "last_updated", b"last_updated", "location", b"location", "mode", b"mode", "name", b"name", "owner", b"owner", "properties", b"properties", "provider", b"provider", "schedule", b"schedule", "source", b"source", "status", b"status", "stream", b"stream", "tags", b"tags", "task_id", b"task_id", "task_id_list", b"task_id_list", "trainingsets", b"trainingsets", "type", b"type", "variant", b"variant"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["location", b"location"]) -> typing.Literal["columns", "function", "stream"] | None: ...

global___FeatureVariant = FeatureVariant

@typing.final
class ValueType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALAR_FIELD_NUMBER: builtins.int
    VECTOR_FIELD_NUMBER: builtins.int
    scalar: global___ScalarType.ValueType
    @property
    def vector(self) -> global___VectorType: ...
    def __init__(
        self,
        *,
        scalar: global___ScalarType.ValueType = ...,
        vector: global___VectorType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Type", b"Type", "scalar", b"scalar", "vector", b"vector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Type", b"Type", "scalar", b"scalar", "vector", b"vector"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Type", b"Type"]) -> typing.Literal["scalar", "vector"] | None: ...

global___ValueType = ValueType

@typing.final
class VectorType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALAR_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    IS_EMBEDDING_FIELD_NUMBER: builtins.int
    scalar: global___ScalarType.ValueType
    dimension: builtins.int
    is_embedding: builtins.bool
    def __init__(
        self,
        *,
        scalar: global___ScalarType.ValueType = ...,
        dimension: builtins.int = ...,
        is_embedding: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dimension", b"dimension", "is_embedding", b"is_embedding", "scalar", b"scalar"]) -> None: ...

global___VectorType = VectorType

@typing.final
class FeatureParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRECOMPUTED_FIELD_NUMBER: builtins.int
    ONDEMAND_FIELD_NUMBER: builtins.int
    @property
    def precomputed(self) -> global___PrecomputedFeatureParameters: ...
    @property
    def ondemand(self) -> global___OndemandFeatureParameters: ...
    def __init__(
        self,
        *,
        precomputed: global___PrecomputedFeatureParameters | None = ...,
        ondemand: global___OndemandFeatureParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["feature_type", b"feature_type", "ondemand", b"ondemand", "precomputed", b"precomputed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["feature_type", b"feature_type", "ondemand", b"ondemand", "precomputed", b"precomputed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["feature_type", b"feature_type"]) -> typing.Literal["precomputed", "ondemand"] | None: ...

global___FeatureParameters = FeatureParameters

@typing.final
class PrecomputedFeatureParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PrecomputedFeatureParameters = PrecomputedFeatureParameters

@typing.final
class OndemandFeatureParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    definition: builtins.str
    def __init__(
        self,
        *,
        definition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["definition", b"definition"]) -> None: ...

global___OndemandFeatureParameters = OndemandFeatureParameters

@typing.final
class FeatureLag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LAG_FIELD_NUMBER: builtins.int
    feature: builtins.str
    variant: builtins.str
    name: builtins.str
    @property
    def lag(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        feature: builtins.str = ...,
        variant: builtins.str = ...,
        name: builtins.str = ...,
        lag: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lag", b"lag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["feature", b"feature", "lag", b"lag", "name", b"name", "variant", b"variant"]) -> None: ...

global___FeatureLag = FeatureLag

@typing.final
class Label(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_VARIANT_FIELD_NUMBER: builtins.int
    VARIANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    default_variant: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def variants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        default_variant: builtins.str = ...,
        variants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_variant", b"default_variant", "name", b"name", "status", b"status", "variants", b"variants"]) -> None: ...

global___Label = Label

@typing.final
class LabelVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TASK_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TASK_ID_LIST_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    description: builtins.str
    entity: builtins.str
    owner: builtins.str
    provider: builtins.str
    task_id: builtins.str
    @property
    def source(self) -> global___NameVariant: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def columns(self) -> global___Columns: ...
    @property
    def stream(self) -> global___Stream: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    @property
    def type(self) -> global___ValueType: ...
    @property
    def task_id_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        description: builtins.str = ...,
        source: global___NameVariant | None = ...,
        entity: builtins.str = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        owner: builtins.str = ...,
        provider: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        columns: global___Columns | None = ...,
        stream: global___Stream | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
        task_id: builtins.str = ...,
        type: global___ValueType | None = ...,
        task_id_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "created", b"created", "location", b"location", "properties", b"properties", "source", b"source", "status", b"status", "stream", b"stream", "tags", b"tags", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "created", b"created", "description", b"description", "entity", b"entity", "location", b"location", "name", b"name", "owner", b"owner", "properties", b"properties", "provider", b"provider", "source", b"source", "status", b"status", "stream", b"stream", "tags", b"tags", "task_id", b"task_id", "task_id_list", b"task_id_list", "trainingsets", b"trainingsets", "type", b"type", "variant", b"variant"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["location", b"location"]) -> typing.Literal["columns", "stream"] | None: ...

global___LabelVariant = LabelVariant

@typing.final
class Provider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SOFTWARE_FIELD_NUMBER: builtins.int
    TEAM_FIELD_NUMBER: builtins.int
    SERIALIZED_CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    type: builtins.str
    software: builtins.str
    team: builtins.str
    serialized_config: builtins.bytes
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        type: builtins.str = ...,
        software: builtins.str = ...,
        team: builtins.str = ...,
        serialized_config: builtins.bytes = ...,
        status: global___ResourceStatus | None = ...,
        sources: collections.abc.Iterable[global___NameVariant] | None = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        labels: collections.abc.Iterable[global___NameVariant] | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["properties", b"properties", "status", b"status", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "features", b"features", "labels", b"labels", "name", b"name", "properties", b"properties", "serialized_config", b"serialized_config", "software", b"software", "sources", b"sources", "status", b"status", "tags", b"tags", "team", b"team", "trainingsets", b"trainingsets", "type", b"type"]) -> None: ...

global___Provider = Provider

@typing.final
class TrainingSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_VARIANT_FIELD_NUMBER: builtins.int
    VARIANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    default_variant: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def variants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        default_variant: builtins.str = ...,
        variants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_variant", b"default_variant", "name", b"name", "status", b"status", "variants", b"variants"]) -> None: ...

global___TrainingSet = TrainingSet

@typing.final
class TrainingSetVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    LAST_UPDATED_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    FEATURE_LAGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_ID_LIST_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    description: builtins.str
    owner: builtins.str
    provider: builtins.str
    schedule: builtins.str
    task_id: builtins.str
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def label(self) -> global___NameVariant: ...
    @property
    def last_updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def feature_lags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureLag]: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    @property
    def task_id_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        description: builtins.str = ...,
        owner: builtins.str = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        provider: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        label: global___NameVariant | None = ...,
        last_updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        schedule: builtins.str = ...,
        feature_lags: collections.abc.Iterable[global___FeatureLag] | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
        task_id: builtins.str = ...,
        task_id_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "label", b"label", "last_updated", b"last_updated", "properties", b"properties", "status", b"status", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created", b"created", "description", b"description", "feature_lags", b"feature_lags", "features", b"features", "label", b"label", "last_updated", b"last_updated", "name", b"name", "owner", b"owner", "properties", b"properties", "provider", b"provider", "schedule", b"schedule", "status", b"status", "tags", b"tags", "task_id", b"task_id", "task_id_list", b"task_id_list", "variant", b"variant"]) -> None: ...

global___TrainingSetVariant = TrainingSetVariant

@typing.final
class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        labels: collections.abc.Iterable[global___NameVariant] | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["properties", b"properties", "status", b"status", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "features", b"features", "labels", b"labels", "name", b"name", "properties", b"properties", "status", b"status", "tags", b"tags", "trainingsets", b"trainingsets"]) -> None: ...

global___Entity = Entity

@typing.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        labels: collections.abc.Iterable[global___NameVariant] | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["properties", b"properties", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "features", b"features", "labels", b"labels", "name", b"name", "properties", b"properties", "tags", b"tags", "trainingsets", b"trainingsets"]) -> None: ...

global___Model = Model

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        labels: collections.abc.Iterable[global___NameVariant] | None = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        sources: collections.abc.Iterable[global___NameVariant] | None = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["properties", b"properties", "status", b"status", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["features", b"features", "labels", b"labels", "name", b"name", "properties", b"properties", "sources", b"sources", "status", b"status", "tags", b"tags", "trainingsets", b"trainingsets"]) -> None: ...

global___User = User

@typing.final
class Source(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_VARIANT_FIELD_NUMBER: builtins.int
    VARIANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    default_variant: builtins.str
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def variants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___ResourceStatus | None = ...,
        default_variant: builtins.str = ...,
        variants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_variant", b"default_variant", "name", b"name", "status", b"status", "variants", b"variants"]) -> None: ...

global___Source = Source

@typing.final
class SourceVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    PRIMARYDATA_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    TRAININGSETS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LAST_UPDATED_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TASK_ID_FIELD_NUMBER: builtins.int
    MAX_JOB_DURATION_FIELD_NUMBER: builtins.int
    TASK_ID_LIST_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    owner: builtins.str
    description: builtins.str
    provider: builtins.str
    table: builtins.str
    schedule: builtins.str
    task_id: builtins.str
    @property
    def transformation(self) -> global___Transformation: ...
    @property
    def primaryData(self) -> global___PrimaryData: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def status(self) -> global___ResourceStatus: ...
    @property
    def trainingsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    @property
    def last_updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def tags(self) -> global___Tags: ...
    @property
    def properties(self) -> global___Properties: ...
    @property
    def max_job_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def task_id_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        transformation: global___Transformation | None = ...,
        primaryData: global___PrimaryData | None = ...,
        owner: builtins.str = ...,
        description: builtins.str = ...,
        provider: builtins.str = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___ResourceStatus | None = ...,
        table: builtins.str = ...,
        trainingsets: collections.abc.Iterable[global___NameVariant] | None = ...,
        features: collections.abc.Iterable[global___NameVariant] | None = ...,
        labels: collections.abc.Iterable[global___NameVariant] | None = ...,
        last_updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        schedule: builtins.str = ...,
        tags: global___Tags | None = ...,
        properties: global___Properties | None = ...,
        task_id: builtins.str = ...,
        max_job_duration: google.protobuf.duration_pb2.Duration | None = ...,
        task_id_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "definition", b"definition", "last_updated", b"last_updated", "max_job_duration", b"max_job_duration", "primaryData", b"primaryData", "properties", b"properties", "status", b"status", "tags", b"tags", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created", b"created", "definition", b"definition", "description", b"description", "features", b"features", "labels", b"labels", "last_updated", b"last_updated", "max_job_duration", b"max_job_duration", "name", b"name", "owner", b"owner", "primaryData", b"primaryData", "properties", b"properties", "provider", b"provider", "schedule", b"schedule", "status", b"status", "table", b"table", "tags", b"tags", "task_id", b"task_id", "task_id_list", b"task_id_list", "trainingsets", b"trainingsets", "transformation", b"transformation", "variant", b"variant"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["definition", b"definition"]) -> typing.Literal["transformation", "primaryData"] | None: ...

global___SourceVariant = SourceVariant

@typing.final
class Transformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQLTRANSFORMATION_FIELD_NUMBER: builtins.int
    DFTRANSFORMATION_FIELD_NUMBER: builtins.int
    KUBERNETES_ARGS_FIELD_NUMBER: builtins.int
    @property
    def SQLTransformation(self) -> global___SQLTransformation: ...
    @property
    def DFTransformation(self) -> global___DFTransformation: ...
    @property
    def kubernetes_args(self) -> global___KubernetesArgs: ...
    def __init__(
        self,
        *,
        SQLTransformation: global___SQLTransformation | None = ...,
        DFTransformation: global___DFTransformation | None = ...,
        kubernetes_args: global___KubernetesArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["DFTransformation", b"DFTransformation", "SQLTransformation", b"SQLTransformation", "args", b"args", "kubernetes_args", b"kubernetes_args", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["DFTransformation", b"DFTransformation", "SQLTransformation", b"SQLTransformation", "args", b"args", "kubernetes_args", b"kubernetes_args", "type", b"type"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["args", b"args"]) -> typing.Literal["kubernetes_args"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["SQLTransformation", "DFTransformation"] | None: ...

global___Transformation = Transformation

@typing.final
class KubernetesResourceSpecs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_REQUEST_FIELD_NUMBER: builtins.int
    CPU_LIMIT_FIELD_NUMBER: builtins.int
    MEMORY_REQUEST_FIELD_NUMBER: builtins.int
    MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    cpu_request: builtins.str
    cpu_limit: builtins.str
    memory_request: builtins.str
    memory_limit: builtins.str
    def __init__(
        self,
        *,
        cpu_request: builtins.str = ...,
        cpu_limit: builtins.str = ...,
        memory_request: builtins.str = ...,
        memory_limit: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cpu_limit", b"cpu_limit", "cpu_request", b"cpu_request", "memory_limit", b"memory_limit", "memory_request", b"memory_request"]) -> None: ...

global___KubernetesResourceSpecs = KubernetesResourceSpecs

@typing.final
class KubernetesArgs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_IMAGE_FIELD_NUMBER: builtins.int
    SPECS_FIELD_NUMBER: builtins.int
    docker_image: builtins.str
    @property
    def specs(self) -> global___KubernetesResourceSpecs: ...
    def __init__(
        self,
        *,
        docker_image: builtins.str = ...,
        specs: global___KubernetesResourceSpecs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["specs", b"specs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["docker_image", b"docker_image", "specs", b"specs"]) -> None: ...

global___KubernetesArgs = KubernetesArgs

@typing.final
class SQLTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    query: builtins.str
    @property
    def source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    def __init__(
        self,
        *,
        query: builtins.str = ...,
        source: collections.abc.Iterable[global___NameVariant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["query", b"query", "source", b"source"]) -> None: ...

global___SQLTransformation = SQLTransformation

@typing.final
class DFTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    SOURCE_TEXT_FIELD_NUMBER: builtins.int
    query: builtins.bytes
    source_text: builtins.str
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameVariant]: ...
    def __init__(
        self,
        *,
        query: builtins.bytes = ...,
        inputs: collections.abc.Iterable[global___NameVariant] | None = ...,
        source_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["inputs", b"inputs", "query", b"query", "source_text", b"source_text"]) -> None: ...

global___DFTransformation = DFTransformation

@typing.final
class PrimaryData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    @property
    def table(self) -> global___PrimarySQLTable: ...
    def __init__(
        self,
        *,
        table: global___PrimarySQLTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["location", b"location", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["location", b"location", "table", b"table"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["location", b"location"]) -> typing.Literal["table"] | None: ...

global___PrimaryData = PrimaryData

@typing.final
class PrimarySQLTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___PrimarySQLTable = PrimarySQLTable

@typing.final
class Tags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        tag: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tag", b"tag"]) -> None: ...

global___Tags = Tags

@typing.final
class Property(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRING_VALUE_FIELD_NUMBER: builtins.int
    string_value: builtins.str
    def __init__(
        self,
        *,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["string_value", b"string_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["string_value", b"string_value", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["string_value"] | None: ...

global___Property = Property

@typing.final
class Properties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Property: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Property | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROPERTY_FIELD_NUMBER: builtins.int
    @property
    def property(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Property]: ...
    def __init__(
        self,
        *,
        property: collections.abc.Mapping[builtins.str, global___Property] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["property", b"property"]) -> None: ...

global___Properties = Properties

@typing.final
class StreamingFeatureVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    entity: builtins.str
    value: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        entity: builtins.str = ...,
        value: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["entity", b"entity", "name", b"name", "ts", b"ts", "value", b"value", "variant", b"variant"]) -> None: ...

global___StreamingFeatureVariant = StreamingFeatureVariant

@typing.final
class StreamingLabelVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VARIANT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    name: builtins.str
    variant: builtins.str
    value: builtins.str
    entity: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        variant: builtins.str = ...,
        value: builtins.str = ...,
        entity: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["entity", b"entity", "name", b"name", "ts", b"ts", "value", b"value", "variant", b"variant"]) -> None: ...

global___StreamingLabelVariant = StreamingLabelVariant
