"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3140],{60561:function(a){function e(a){a.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}a.exports=e,e.displayName="hsts",e.aliases=[]}}]);