"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9674],{12208:function(e){function n(e){e.languages.gcode={comment:/;.*|\B\(.*?\)\B/,string:{pattern:/"(?:""|[^"])*"/,greedy:!0},keyword:/\b[GM]\d+(?:\.\d+)?\b/,property:/\b[A-Z]/,checksum:{pattern:/(\*)\d+/,lookbehind:!0,alias:"number"},punctuation:/[:*]/}}e.exports=n,n.displayName="gcode",n.aliases=[]}}]);