"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[902],{9858:function(a){function e(a){var e,n;Object.defineProperty(n=(e=a).languages.javadoclike={parameter:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*@(?:arg|arguments|param)\s+)\w+/m,lookbehind:!0},keyword:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*|\{)@[a-z][a-zA-Z-]+\b/m,lookbehind:!0},punctuation:/[{}]/},"addSupport",{value:function(a,n){"string"==typeof a&&(a=[a]),a.forEach(function(a){!function(a,n){var t="doc-comment",r=e.languages[a];if(r){var i=r[t];if(!i){var o={};o[t]={pattern:/(^|[^\\])\/\*\*[^/][\s\S]*?(?:\*\/|$)/,lookbehind:!0,alias:"comment"},i=(r=e.languages.insertBefore(a,"comment",o))[t]}if(i instanceof RegExp&&(i=r[t]={pattern:i}),Array.isArray(i))for(var s=0,p=i.length;s<p;s++)i[s]instanceof RegExp&&(i[s]={pattern:i[s]}),n(i[s]);else n(i)}}(a,function(a){a.inside||(a.inside={}),a.inside.rest=n})})}}),n.addSupport(["java","javascript","php"],n)}a.exports=e,e.displayName="javadoclike",e.aliases=[]}}]);